==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/Storage/AmazonElasticFileSystemStandard.md <==
# AmazonElasticFileSystemStandard


```text
aws-q3-2021/Resource/Storage/AmazonElasticFileSystemStandard
```

```text
include('aws-q3-2021/Resource/Storage/AmazonElasticFileSystemStandard')
```



| Illustration | AmazonElasticFileSystemStandard | AmazonElasticFileSystemStandardCard | AmazonElasticFileSystemStandardGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Storage/AmazonElasticFileSystemStandard.png) | ![illustration for AmazonElasticFileSystemStandard](../../../aws-q3-2021/Resource/Storage/AmazonElasticFileSystemStandard.Local.png) | ![illustration for AmazonElasticFileSystemStandardCard](../../../aws-q3-2021/Resource/Storage/AmazonElasticFileSystemStandardCard.Local.png) | ![illustration for AmazonElasticFileSystemStandardGroup](../../../aws-q3-2021/Resource/Storage/AmazonElasticFileSystemStandardGroup.Local.png) |




## AmazonElasticFileSystemStandard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonElasticFileSystemStandard
include('aws-q3-2021/Resource/Storage/AmazonElasticFileSystemStandard')

' renders the element
AmazonElasticFileSystemStandard('AmazonElasticFileSystemStandard', 'Amazon Elastic File System Standard', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonElasticFileSystemStandard
include('aws-q3-2021/Resource/Storage/AmazonElasticFileSystemStandard')

' renders the element
AmazonElasticFileSystemStandard('AmazonElasticFileSystemStandard', 'Amazon Elastic File System Standard', 'an optional tech label')
@enduml
```

## AmazonElasticFileSystemStandardCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonElasticFileSystemStandardCard
include('aws-q3-2021/Resource/Storage/AmazonElasticFileSystemStandard')

' renders the element
AmazonElasticFileSystemStandardCard('AmazonElasticFileSystemStandardCard', 'Amazon Elastic File System Standard Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonElasticFileSystemStandardCard
include('aws-q3-2021/Resource/Storage/AmazonElasticFileSystemStandard')

' renders the element
AmazonElasticFileSystemStandardCard('AmazonElasticFileSystemStandardCard', 'Amazon Elastic File System Standard Card', 'an optional description')
@enduml
```

## AmazonElasticFileSystemStandardGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonElasticFileSystemStandardGroup
include('aws-q3-2021/Resource/Storage/AmazonElasticFileSystemStandard')

' renders the element
AmazonElasticFileSystemStandardGroup('AmazonElasticFileSystemStandardGroup', 'Amazon Elastic File System Standard Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonElasticFileSystemStandardGroup
include('aws-q3-2021/Resource/Storage/AmazonElasticFileSystemStandard')

' renders the element
AmazonElasticFileSystemStandardGroup('AmazonElasticFileSystemStandardGroup', 'Amazon Elastic File System Standard Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-q3-2021/Resource/Storage/AmazonElasticFileSystemStandard.md <==
# AmazonElasticFileSystemStandard


```text
aws-q3-2021/Resource/Storage/AmazonElasticFileSystemStandard
```

```text
include('aws-q3-2021/Resource/Storage/AmazonElasticFileSystemStandard')
```



| Illustration | AmazonElasticFileSystemStandard | AmazonElasticFileSystemStandardCard | AmazonElasticFileSystemStandardGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Storage/AmazonElasticFileSystemStandard.png) | ![illustration for AmazonElasticFileSystemStandard](../../../aws-q3-2021/Resource/Storage/AmazonElasticFileSystemStandard.Local.png) | ![illustration for AmazonElasticFileSystemStandardCard](../../../aws-q3-2021/Resource/Storage/AmazonElasticFileSystemStandardCard.Local.png) | ![illustration for AmazonElasticFileSystemStandardGroup](../../../aws-q3-2021/Resource/Storage/AmazonElasticFileSystemStandardGroup.Local.png) |




## AmazonElasticFileSystemStandard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonElasticFileSystemStandard
include('aws-q3-2021/Resource/Storage/AmazonElasticFileSystemStandard')

' renders the element
AmazonElasticFileSystemStandard('AmazonElasticFileSystemStandard', 'Amazon Elastic File System Standard', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonElasticFileSystemStandard
include('aws-q3-2021/Resource/Storage/AmazonElasticFileSystemStandard')

' renders the element
AmazonElasticFileSystemStandard('AmazonElasticFileSystemStandard', 'Amazon Elastic File System Standard', 'an optional tech label')
@enduml
```

## AmazonElasticFileSystemStandardCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonElasticFileSystemStandardCard
include('aws-q3-2021/Resource/Storage/AmazonElasticFileSystemStandard')

' renders the element
AmazonElasticFileSystemStandardCard('AmazonElasticFileSystemStandardCard', 'Amazon Elastic File System Standard Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonElasticFileSystemStandardCard
include('aws-q3-2021/Resource/Storage/AmazonElasticFileSystemStandard')

' renders the element
AmazonElasticFileSystemStandardCard('AmazonElasticFileSystemStandardCard', 'Amazon Elastic File System Standard Card', 'an optional description')
@enduml
```

## AmazonElasticFileSystemStandardGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonElasticFileSystemStandardGroup
include('aws-q3-2021/Resource/Storage/AmazonElasticFileSystemStandard')

' renders the element
AmazonElasticFileSystemStandardGroup('AmazonElasticFileSystemStandardGroup', 'Amazon Elastic File System Standard Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonElasticFileSystemStandardGroup
include('aws-q3-2021/Resource/Storage/AmazonElasticFileSystemStandard')

' renders the element
AmazonElasticFileSystemStandardGroup('AmazonElasticFileSystemStandardGroup', 'Amazon Elastic File System Standard Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
